{% extends "base.html" %}

{% block main %}
<div class="row">

  <div class="col-md-4 col-xs-12 col-md-offset-4 login-form">
    <h2>{{ _("Login to %(site_name)s", site_name=config.SITE_NAME) }}</h2>

    <form action="{{ url_for('.login_post') }}" method="POST" name="login" role="form">
      <div class="form-group">
        <input type="text" name="email" placeholder="E-Mail" value="{{ email|default }}"
               class="form-control" autofocus="autofocus" />
      </div>
      <div class="form-group">
        <input type="password" name="password" placeholder="{{ _('Password') }}" class="form-control" />
      </div>

      <div class="form-group">
          <input type="hidden" name="next" value="{{ next_url or '' }}" />
          <button class="btn btn-primary" type="submit" style="float: left">{{ _("Sign in") }}</button>
          <span style="display: inline-block; float:right; text-align: right;">
            <a href="{{ url_for('.forgotten_pw_form') }}">{{ _("Forgot password?") }}</a>
          </span>
      </div>
    </form>
  </div>

</div>
{% endblock %}
